import { defineStore } from 'pinia'
import { ref } from 'vue'
import { login, adminUsersRead } from '@/api/user'
import router from '@/router'
import { showLoadingToast, closeToast } from 'vant'

export const useUserStore = defineStore('useUserStore', () => {
  const userInfo = ref({
    token: '',
    realname: '',
    deptName: '',
    email: ''
  })

  const code = ref('')
  const _login = async (_data) => {
    showLoadingToast({
      message: '登录中...',
      forbidClick: true,
      loadingType: 'spinner',
    });
    const data = await login(_data)

    if (data.code === 0) {
      userInfo.value.token = data['Admin-Token']
      // eslint-disable-next-line no-undef
      adminUsersRead().then(res => {
        closeToast()
        userInfo.value = {
          ...res.data,
          token: data['Admin-Token']
        }
        console.log('跳转啊');
        
        router.push({
          path: '/todo'
        })
      })
    }
    return data.code
  }

  const logout = () => {
    userInfo.value = {
      id: '',
      name: '',
      phone: '',
      token: ''
    }
    router.push({
      path: '/login'
    })
  }

  return {
    userInfo,
    code,
    login: _login,
    logout
  }
}, {
  persist: true
})
